.. _utilipy-utils-typing:

*******************************
Typing (`utilipy.utils.typing`)
*******************************

.. currentmodule:: utilipy.utils.typing


Reference/API
=============

.. automodapi:: utilipy.utils.typing
